
import requests
import urllib3
urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
try:
    from urllib.parse import urljoin
except ImportError:
    from urlparse import urljoin


class AirMaxAPIClient(object):
    def __init__(self, **kwargs):
        '''
            Args:
                :username (str): Username for login
                :password (str): Password for login
                :url (str): Weburl for the unifi Airmax
                :verify (bool): Verify certs
                :proxy (str): Set proxy path
            Returns:
                :AirMaxAPIClient (object): 

        '''
        self.username = kwargs['username']
        self.password = kwargs['password']
        self.url = kwargs['url']
        self.verify = kwargs.get('verify', True)
        proxy = kwargs.get('proxy', None)
        self.proxies = None
        if proxy:
            self.proxies = {
                'http': proxy,
                'https': proxy
            }
        self.session = None

    def path(self, path):
        '''
            builds up the complete URL

            Args:
                :path (str): Ressource extension
                :path (list): list of separated Ressource extensions

            Returns:
                :url (str): '<self.url/path>'
        '''

        return urljoin(self.url, path)

    def login(self):
        '''
            Login to the unifi AirMax Device
            Setup the session

            Returns:
                :status (bool): True success False failure
        '''
        self.session = requests.Session()
        self.session.proxies = self.proxies
        self.session.verify = self.verify
        url = self.path('api/auth')
        params = {
            'username': self.username,
            'password': self.password
        }
        login = self.session.post(url, data=params)
        return login.ok

    def logout(self):
        '''
            Logout the unifi AirMax Device
            Reset the session

            Returns:
                :status (bool): True success False failure
        '''
        if not self.session:
            raise Exception("You need to login")
        url = self.path('logout.cgi')
        logout = self.session.post(url)
        self.session = None
        return logout.ok

    def statistics(self):
        '''
            Get the statistics from the device

            Return:
                :statistics (dict): Device specific statistics
        '''
        if not self.session:
            raise Exception("You are not logged in.")
        url = self.path('status.cgi')
        response = self.session.get(url)
        return response.json()



#!/usr/bin/env python3
"""A setuptools based setup module.
See:
    https://packaging.python.org/en/latest/distributing.html
    https://github.com/pypa/sampleproject
"""

# To use a consistent encoding
import os
from os import path
from unifi_client import __version__ as VERSION
# Always prefer setuptools over distutils
from setuptools import setup, find_packages

HERE = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(HERE, 'README.md'), encoding='utf-8') as f:
    LONG_DESCRIPTION = f.read()

setup(
    name='unifi_client',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version='{}'.format(VERSION),

    description='Ubiquiti Unifi REST API Client.',
    long_description=LONG_DESCRIPTION,

    # The project's main homepage.
    url='https://github.com/Selfnet/unifi_client',

    # Author details
    author='Marcel Fest',
    author_email='marcelf@selfnet.de',

    # Choose your license
    license='MIT',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 4 - Beta',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3'
    ],

    # What does your project relate to?
    keywords='metric prometheus unifi ubnt ubiquiti ap access point',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=find_packages(
        exclude=['bin', 'lib', 'contrib', 'docs', 'tests', 'prometheus', 'env']),

    # Alternatively, if you want to distribute just a my_module.py, uncomment
    # this:
    # py_modules=["Multivault"],

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=['requests'],

    # List additional groups of dependencies here (e.g. development
    # dependencies). You can install these using the following syntax,
    # for example:
    # $ pip install -e .[dev,test]
    extras_require={
        'dev': ['pylint', 'autopep8', 'pep8', 'PySocks'],
        'socks': ['PySocks'],
    },
)
